@@ -2,9 +2,8 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
-from . import product
-from . import configuration
-from . import account
+
+from . import account, analytic_account, configuration, product
 
 
 def register():
@@ -21,6 +20,10 @@ def register():
         configuration.Configuration,
         configuration.ConfigurationDefaultAccount,
         module='account_product', type_='model')
+    Pool.register(
+        account.MoveLine,
+        analytic_account.Rule,
+        module='account_product', type_='model', depends=['analytic_account'])
     Pool.register(
         account.CreateChart,
         module='account_product', type_='wizard')
