@@ -1,8 +1,8 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-from trytond.pool import PoolMeta, Pool
-from trytond.pyson import Eval
 from trytond.model import fields
+from trytond.pool import Pool, PoolMeta
+from trytond.pyson import Eval
 from trytond.transaction import Transaction
 
 
@@ -15,16 +15,14 @@ class CreateChartProperties(metaclass=PoolMeta):
             ('closed', '!=', True),
             ('type.expense', '=', True),
             ('company', '=', Eval('company')),
-            ],
-        depends=['company'])
+            ])
     category_account_revenue = fields.Many2One(
         'account.account', 'Default Revenue Account',
         domain=[
             ('closed', '!=', True),
             ('type.revenue', '=', True),
             ('company', '=', Eval('company')),
-            ],
-        depends=['company'])
+            ])
 
 
 class CreateChart(metaclass=PoolMeta):
@@ -60,8 +58,12 @@ class CreateChart(metaclass=PoolMeta):
                 ], limit=2)
         if len(expense_accounts) == 1:
             defaults['category_account_expense'] = expense_accounts[0].id
+        else:
+            defaults['category_account_expense'] = None
         if len(revenue_accounts) == 1:
             defaults['category_account_revenue'] = revenue_accounts[0].id
+        else:
+            defaults['category_account_revenue'] = None
         return defaults
 
 
